summaryrefslogtreecommitdiff
path: root/chip/nrf51/bluetooth_le.h
diff options
context:
space:
mode:
authorPaul Fagerburg <pfagerburg@google.com>2020-07-27 15:52:15 -0600
committerCommit Bot <commit-bot@chromium.org>2020-07-28 22:59:41 +0000
commit6efabc79d3519baa56ba1c065035a491fc6918ec (patch)
tree9981d7bbdc897ef485226c8f13000c4a2ef83403 /chip/nrf51/bluetooth_le.h
parent63498074bd3a77b28d2a96ef43aeceed51aa2bde (diff)
downloadchrome-ec-6efabc79d3519baa56ba1c065035a491fc6918ec.tar.gz
ec: change usage of whitelist/blacklist
Google is working to change its source code to use more inclusive language. To that end, replace the terms "whitelist", "blacklist", and similar with inclusive alternatives. BUG=b:162262297 BRANCH=None TEST=`grep -Eirl "(white|black)[ _\-]*list" .` The only results are in "private/nordic_keyboard/sdk8.0.0" which is not our code. Signed-off-by: Paul Fagerburg <pfagerburg@google.com> Change-Id: Ie5210b98e1096c22d0e9284c101a42820bd3d79d Reviewed-on: https://chromium-review.googlesource.com/c/chromiumos/platform/ec/+/2321549 Tested-by: Paul Fagerburg <pfagerburg@chromium.org> Reviewed-by: Jett Rink <jettrink@chromium.org> Commit-Queue: Paul Fagerburg <pfagerburg@chromium.org>
Diffstat (limited to 'chip/nrf51/bluetooth_le.h')
-rw-r--r--chip/nrf51/bluetooth_le.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/chip/nrf51/bluetooth_le.h b/chip/nrf51/bluetooth_le.h
index a2b3807a7e..dbb3bccd6e 100644
--- a/chip/nrf51/bluetooth_le.h
+++ b/chip/nrf51/bluetooth_le.h
@@ -52,19 +52,19 @@ void ble_tx(struct ble_pdu *pdu);
/* Receive a packet into pdu if one comes before the timeout */
int ble_rx(struct ble_pdu *pdu, int timeout, int adv);
-/* White list handling */
+/* Allow list handling */
-/* Clear the white list */
-int ble_radio_clear_white_list(void);
+/* Clear the allow list */
+int ble_radio_clear_allow_list(void);
-/* Read the size of the white list and assign it to ret_size */
-int ble_radio_read_white_list_size(uint8_t *ret_size);
+/* Read the size of the allow list and assign it to ret_size */
+int ble_radio_read_allow_list_size(uint8_t *ret_size);
/* Add the device with the address specified by addr_ptr and type */
-int ble_radio_add_device_to_white_list(const uint8_t *addr_ptr, uint8_t type);
+int ble_radio_add_device_to_allow_list(const uint8_t *addr_ptr, uint8_t type);
/* Remove the device with the address specified by addr_ptr and type */
-int ble_radio_remove_device_from_white_list(const uint8_t *addr_ptr,
+int ble_radio_remove_device_from_allow_list(const uint8_t *addr_ptr,
uint8_t type);
#endif /* __NRF51_BLUETOOTH_LE_H */